@@ -2,6 +2,7 @@ import json
 import os
 import time
 
+import curlify
 import requests
 from decorator import decorator
 
@@ -53,9 +54,10 @@ def logged_request(method, url, **kwargs):
         start_time = int(time.time() * 1000)
 
         try:
-            # header_dict: dict = kwargs.get('headers', None)
-            # if header_dict is not None:
-            #     header_dict.update(trace())
+            header_dict: dict = kwargs.get('headers', None)
+            zone = os.environ.get("ZONE", None)
+            if header_dict is not None and zone is not None and "nonpcidss" in zone:
+                header_dict.update(trace())
             response = original_request_method(method, url, **kwargs)
             request = response.request
         finally:
@@ -204,6 +206,7 @@ def push_to_prometheus(prometheus_push_body):
         print(f"Push to prometheus : {response.text}")
         return
     else:
+        print(f"Failed to push to prometheus : {curlify.to_curl(response.request)}")
         raise TypeError("Could not push data to prometheus.")
 
 
