@@ -187,10 +187,10 @@ class Utilities(object):
         # functionalParm.curl_request(response.request.url,requestMethod,headers,jsonPayload)
         # logger.info("--------CURL END---------")
         try:
-            assert response.status_code != expectedStatusCode, \
-                f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match with failure reason {response.json()}"
+            assert response.status_code == expectedStatusCode, \
+                f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match with failure reason"
             return response
         except:
-            logger.error(response.headers)
-            pytest.fail(f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match and response is {response.json()}")
+            # logger.error(response.headers)
+            pytest.fail(f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match")
 
